@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.10.4');
+use version; our $VERSION = qv('v0.10.6');
 
 use 5.010;
 use	Moose;
@@ -45,7 +45,7 @@ my	$parser_modules ={
 			styles =>{
 				superclasses			=> ['Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles'],
 				attributes				=> [qw( epoch_year error_inst )],
-				add_roles_in_sequence	=> [qw( default_format_list format_string_parser )],#### Does self cover excel_epoch?
+				add_roles_in_sequence	=> [qw( default_format_list format_string_parser )],
 				store					=> '_set_styles_instance',
 				package					=> 'StylesInstance',
 			},
@@ -300,7 +300,7 @@ has _styles_instance =>(
 		writer		=> '_set_styles_instance',
 		clearer		=> '_clear_styles',
 		predicate	=> '_has_styles_file',
-		handles		=>[ 'get_format_position' ],
+		handles		=>[ 'get_format_position', 'set_defined_excel_format_list' ],
 	);
 
 has _calc_chain_instance =>(
@@ -716,6 +716,7 @@ Spreadsheet::XLSX::Reader::LibXML - Read xlsx spreadsheet files with LibXML
 
 The following uses the 'TestBook.xlsx' file found in the t/test_files/ folder
 
+	#!/usr/bin/env perl
 	use strict;
 	use warnings;
 	use Spreadsheet::XLSX::Reader::LibXML;
@@ -817,6 +818,28 @@ option.  Additionally this package does not (yet) provide the same access to the
 elements provided in L<Spreadsheet::ParseExcel>.  That is on the longish and incomplete TODO 
 list.
 
+The package operates on the workbook with three primary tiers of classes.  All other classes 
+in this package are for architectual extensibility.
+
+=over
+
+---> Workbook level (This class)
+
+=over
+
+---> L<Worksheet level|Spreadsheet::XLSX::Reader::LibXML::Worksheet>
+
+=over
+
+---> L<Cell level|Spreadsheet::XLSX::Reader::LibXML::Cell> - 
+L<optional|/group_return_type>
+
+=back
+
+=back
+
+=back
+
 =head2 Primary Methods
 
 These are the primary ways to use this class.  They can be used to open an .xlsx 
@@ -1007,10 +1030,10 @@ attributes set as;
 B<Range:> The minimum list of methods to implement for your own instance is;
 
 	error set_error clear_error set_warnings if_warn
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 get_error_inst
 
@@ -1071,10 +1094,10 @@ xlsx file to be parsed.
 B<Default> no default - this must be provided to read a file
 
 B<Range> any unincrypted xlsx file that can be opened in Microsoft Excel
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 set_file_name
 
@@ -1103,10 +1126,10 @@ yourself.>
 B<Default> the value from the file
 
 B<Range> A string
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 creator
 
@@ -1127,10 +1150,10 @@ yourself.>
 B<Default> the value from the file
 
 B<Range> A timestamp string (ISO ish)
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 date_created
 
@@ -1151,10 +1174,10 @@ yourself.>
 B<Default> the value from the file
 
 B<Range> A string
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 modified_by
 
@@ -1175,10 +1198,10 @@ yourself.>
 B<Default> the value from the file
 
 B<Range> A timestamp string (ISO ish)
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 date_modified
 
@@ -1198,10 +1221,10 @@ choice is 'reader'.
 B<Default> 'reader'
 
 B<Range> 'reader'
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 set_parser_type
 
@@ -1230,10 +1253,10 @@ B<Default> 1
 
 B<Range> 1 = counting from zero like Spreadsheet::ParseExcel, 
 0 = Counting from 1 lke Excel
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 counting_from_zero
 
@@ -1265,10 +1288,10 @@ B<Default> 1
 
 B<Range> 1 = return 'EOR' or 'EOF' flags as appropriate,
 0 = return undef when requesting a position that is out of bounds
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 boundary_flag_setting
 
@@ -1300,10 +1323,10 @@ B<Default> 0
 B<Range> 1 = treat all columns short of the max column for the sheet as being in 
 the table, 0 = end each row after the last cell with data rather than going to the 
 max sheet column
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 is_empty_the_end
 
@@ -1335,10 +1358,10 @@ B<Default> 1
 B<Range> 1 = treat the top left corner of the sheet even if there is no data in 
 the top row or leftmost column, 0 = Set the minimum row and minimum columns to be 
 the first row and first column with data
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 set_from_the_edge
 
@@ -1363,10 +1386,10 @@ B<Range> a L<Moose> role with the methods 'get_defined_excel_format' and
 for L<XML::LibXML> allways attempts to get the data into perl friendly strings.  That 
 means this should only tweak the data on the way out and does not affect the data on the 
 way in.
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 get_default_format_list
 
@@ -1394,10 +1417,10 @@ If you don't like the output or the method you can write your own Moose Role and
 B<Default> Spreadsheet::XLSX::Reader::LibXML::ParseExcelFormatStrings
 
 B<Range> a L<Moose> role with the method 'parse_excel_format_string'
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 get_format_string_parser
 
@@ -1433,10 +1456,10 @@ B<Default> instance
 B<Range> instance = returns a populated L<Spreadsheet::XLSX::Reader::LibXML::Cell> instance,
 unformatted = returns the raw value of the cell with no modifications, value = returns just 
 the formatted value stored in the excel cell
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
+		
+=back
 
 =head4 get_group_return_type
 
